@@ -267,11 +267,32 @@ impl DevGroupsSpecification {
 
     /// Returns `true` if the group is included in the specification.
     pub fn contains(&self, group: &GroupName) -> bool {
-        self.dev.as_ref().map_or(false, |dev| dev.contains(group))
-            || self
-                .groups
-                .as_ref()
-                .map_or(false, |groups| groups.contains(group))
+        if group == &*DEV_DEPENDENCIES {
+            match self.dev.as_ref() {
+                None => {}
+                Some(DevMode::Exclude) => {
+                    // If `--no-dev` was provided, always exclude dev.
+                    return false;
+                }
+                Some(DevMode::Only) => {
+                    // If `--only-dev` was provided, always include dev.
+                    return true;
+                }
+                Some(DevMode::Include) => {
+                    // If `--no-group dev` was provided, exclude dev.
+                    return match self.groups.as_ref() {
+                        Some(GroupsSpecification::Include { exclude, .. }) => {
+                            !exclude.contains(group)
+                        }
+                        _ => true,
+                    };
+                }
+            }
+        }
+
+        self.groups
+            .as_ref()
+            .map_or(false, |groups| groups.contains(group))
     }
 }
 
@@ -325,6 +346,18 @@ impl DevGroupsManifest {
         self.spec.prod()
     }
 
+    /// Returns `true` if the group was enabled by default.
+    pub fn default(&self, group: &GroupName) -> bool {
+        if self.spec.contains(group) {
+            // If the group was explicitly requested, then it wasn't enabled by default.
+            false
+        } else {
+            // If the group was enabled, but wasn't explicitly requested, then it was enabled by
+            // default.
+            self.contains(group)
+        }
+    }
+
     /// Returns `true` if the group is included in the manifest.
     pub fn contains(&self, group: &GroupName) -> bool {
         if self.spec.contains(group) {
