@@ -49,7 +49,7 @@ impl LoweredRequirement {
         git_member: Option<&'data GitWorkspaceMember<'data>>,
     ) -> impl Iterator<Item = Result<Self, LoweringError>> + 'data {
         // Identify the source from the `tool.uv.sources` table.
-        let (source, origin) = if let Some(source) = project_sources.get(&requirement.name) {
+        let (sources, origin) = if let Some(source) = project_sources.get(&requirement.name) {
             (Some(source), RequirementOrigin::Project)
         } else if let Some(source) = workspace.sources().get(&requirement.name) {
             (Some(source), RequirementOrigin::Workspace)
@@ -58,8 +58,8 @@ impl LoweredRequirement {
         };
 
         // If the source only applies to a given extra or dependency group, filter it out.
-        let source = source.map(|source| {
-            source
+        let sources = sources.map(|sources| {
+            sources
                 .iter()
                 .filter(|source| {
                     if let Some(target) = source.extra() {
@@ -80,23 +80,62 @@ impl LoweredRequirement {
                 .collect::<Sources>()
         });
 
-        let workspace_package_declared =
-            // We require that when you use a package that's part of the workspace, ...
-            !workspace.packages().contains_key(&requirement.name)
-                // ... it must be declared as a workspace dependency (`workspace = true`), ...
-                || source.as_ref().filter(|sources| !sources.is_empty()).is_some_and(|source| source.iter().all(|source| {
-                    matches!(source, Source::Workspace { workspace: true, .. })
-                }))
-                // ... except for recursive self-inclusion (extras that activate other extras), e.g.
-                // `framework[machine_learning]` depends on `framework[cuda]`.
-                || project_name.is_some_and(|project_name| *project_name == requirement.name);
-        if !workspace_package_declared {
-            return Either::Left(std::iter::once(Err(
-                LoweringError::UndeclaredWorkspacePackage,
-            )));
+        // If you use a package that's part of the workspace...
+        if workspace.packages().contains_key(&requirement.name) {
+            // And it's not a recursive self-inclusion (extras that activate other extras), e.g.
+            // `framework[machine_learning]` depends on `framework[cuda]`.
+            if !project_name.is_some_and(|project_name| *project_name == requirement.name) {
+                // It must be declared as a workspace source.
+                let Some(sources) = sources.as_ref() else {
+                    // No sources were declared for the workspace package.
+                    return Either::Left(std::iter::once(Err(
+                        LoweringError::MissingWorkspaceSource(requirement.name.clone()),
+                    )));
+                };
+
+                for source in sources.iter() {
+                    match source {
+                        Source::Git { .. } => {
+                            return Either::Left(std::iter::once(Err(
+                                LoweringError::NonWorkspaceSource(
+                                    requirement.name.clone(),
+                                    SourceKind::Git,
+                                ),
+                            )));
+                        }
+                        Source::Url { .. } => {
+                            return Either::Left(std::iter::once(Err(
+                                LoweringError::NonWorkspaceSource(
+                                    requirement.name.clone(),
+                                    SourceKind::Url,
+                                ),
+                            )));
+                        }
+                        Source::Path { .. } => {
+                            return Either::Left(std::iter::once(Err(
+                                LoweringError::NonWorkspaceSource(
+                                    requirement.name.clone(),
+                                    SourceKind::Path,
+                                ),
+                            )));
+                        }
+                        Source::Registry { .. } => {
+                            return Either::Left(std::iter::once(Err(
+                                LoweringError::NonWorkspaceSource(
+                                    requirement.name.clone(),
+                                    SourceKind::Registry,
+                                ),
+                            )));
+                        }
+                        Source::Workspace { .. } => {
+                            // OK
+                        }
+                    }
+                }
+            }
         }
 
-        let Some(source) = source else {
+        let Some(sources) = sources else {
             let has_sources = !project_sources.is_empty() || !workspace.sources().is_empty();
             if matches!(lower_bound, LowerBound::Warn) {
                 // Support recursive editable inclusions.
@@ -118,13 +157,13 @@ impl LoweredRequirement {
         let remaining = {
             // Determine the space covered by the sources.
             let mut total = MarkerTree::FALSE;
-            for source in source.iter() {
-                total.or(source.marker().clone());
+            for source in sources.iter() {
+                total.or(source.marker());
             }
 
             // Determine the space covered by the requirement.
             let mut remaining = total.negate();
-            remaining.and(requirement.marker.clone());
+            remaining.and(requirement.marker);
 
             LoweredRequirement(Requirement {
                 marker: remaining,
@@ -133,7 +172,7 @@ impl LoweredRequirement {
         };
 
         Either::Right(
-            source
+            sources
                 .into_iter()
                 .map(move |source| {
                     let (source, mut marker) = match source {
@@ -181,6 +220,7 @@ impl LoweredRequirement {
                             }
                             let source = path_source(
                                 PathBuf::from(path),
+                                git_member,
                                 origin,
                                 project_dir,
                                 workspace.install_path(),
@@ -242,7 +282,11 @@ impl LoweredRequirement {
                             let member = workspace
                                 .packages()
                                 .get(&requirement.name)
-                                .ok_or(LoweringError::UndeclaredWorkspacePackage)?
+                                .ok_or_else(|| {
+                                    LoweringError::UndeclaredWorkspacePackage(
+                                        requirement.name.clone(),
+                                    )
+                                })?
                                 .clone();
 
                             // Say we have:
@@ -271,11 +315,12 @@ impl LoweredRequirement {
                             })?;
 
                             let source = if let Some(git_member) = &git_member {
-                                // If the workspace comes from a git dependency, all workspace
-                                // members need to be git deps, too.
-                                let subdirectory =
-                                    uv_fs::relative_to(member.root(), git_member.fetch_root)
-                                        .expect("Workspace member must be relative");
+                                // If the workspace comes from a Git dependency, all workspace
+                                // members need to be Git dependencies, too.
+                                let subdirectory = uv_fs::normalize_path(
+                                    &uv_fs::relative_to(member.root(), git_member.fetch_root)
+                                        .expect("Workspace member must be relative"),
+                                );
                                 RequirementSource::Git {
                                     repository: git_member.git_source.git.repository().clone(),
                                     reference: git_member.git_source.git.reference().clone(),
@@ -306,7 +351,7 @@ impl LoweredRequirement {
                         }
                     };
 
-                    marker.and(requirement.marker.clone());
+                    marker.and(requirement.marker);
 
                     Ok(Self(Requirement {
                         name: requirement.name.clone(),
@@ -360,12 +405,12 @@ impl LoweredRequirement {
             // Determine the space covered by the sources.
             let mut total = MarkerTree::FALSE;
             for source in source.iter() {
-                total.or(source.marker().clone());
+                total.or(source.marker());
             }
 
             // Determine the space covered by the requirement.
             let mut remaining = total.negate();
-            remaining.and(requirement.marker.clone());
+            remaining.and(requirement.marker);
 
             LoweredRequirement(Requirement {
                 marker: remaining,
@@ -422,6 +467,7 @@ impl LoweredRequirement {
                             }
                             let source = path_source(
                                 PathBuf::from(path),
+                                None,
                                 RequirementOrigin::Project,
                                 dir,
                                 dir,
@@ -458,7 +504,7 @@ impl LoweredRequirement {
                         }
                     };
 
-                    marker.and(requirement.marker.clone());
+                    marker.and(requirement.marker);
 
                     Ok(Self(Requirement {
                         name: requirement.name.clone(),
@@ -486,8 +532,12 @@ impl LoweredRequirement {
 /// `project.{dependencies,optional-dependencies}`.
 #[derive(Debug, Error)]
 pub enum LoweringError {
-    #[error("Package is not included as workspace package in `tool.uv.workspace`")]
-    UndeclaredWorkspacePackage,
+    #[error("`{0}` is included as a workspace member, but is missing an entry in `tool.uv.sources` (e.g., `{0} = {{ workspace = true }}`)")]
+    MissingWorkspaceSource(PackageName),
+    #[error("`{0}` is included as a workspace member, but references a {1} in `tool.uv.sources`. Workspace members must be declared as workspace sources (e.g., `{0} = {{ workspace = true }}`).")]
+    NonWorkspaceSource(PackageName, SourceKind),
+    #[error("`{0}` references a workspace in `tool.uv.sources` (e.g., `{0} = {{ workspace = true }}`), but is not a workspace member")]
+    UndeclaredWorkspacePackage(PackageName),
     #[error("Can only specify one of: `rev`, `tag`, or `branch`")]
     MoreThanOneGitRef,
     #[error("Package `{0}` references an undeclared index: `{1}`")]
@@ -506,6 +556,8 @@ pub enum LoweringError {
     WorkspaceFalse,
     #[error("Editable must refer to a local directory, not a file: `{0}`")]
     EditableFile(String),
+    #[error("Git repository references local file source, but only directories are supported as transitive Git dependencies: `{0}`")]
+    GitFile(String),
     #[error(transparent)]
     ParsedUrl(#[from] ParsedUrlError),
     #[error("Path must be UTF-8: `{0}`")]
@@ -514,6 +566,25 @@ pub enum LoweringError {
     RelativeTo(io::Error),
 }
 
+#[derive(Debug, Copy, Clone)]
+pub enum SourceKind {
+    Path,
+    Url,
+    Git,
+    Registry,
+}
+
+impl std::fmt::Display for SourceKind {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            SourceKind::Path => write!(f, "path"),
+            SourceKind::Url => write!(f, "URL"),
+            SourceKind::Git => write!(f, "Git"),
+            SourceKind::Registry => write!(f, "registry"),
+        }
+    }
+}
+
 /// Convert a Git source into a [`RequirementSource`].
 fn git_source(
     git: &Url,
@@ -612,6 +683,7 @@ fn registry_source(
 /// Convert a path string to a file or directory source.
 fn path_source(
     path: impl AsRef<Path>,
+    git_member: Option<&GitWorkspaceMember>,
     origin: RequirementOrigin,
     project_dir: &Path,
     workspace_root: &Path,
@@ -636,6 +708,24 @@ fn path_source(
         install_path.extension().is_none()
     };
     if is_dir {
+        if let Some(git_member) = git_member {
+            let subdirectory = uv_fs::normalize_path(
+                &uv_fs::relative_to(install_path, git_member.fetch_root)
+                    .expect("Workspace member must be relative"),
+            );
+            return Ok(RequirementSource::Git {
+                repository: git_member.git_source.git.repository().clone(),
+                reference: git_member.git_source.git.reference().clone(),
+                precise: git_member.git_source.git.precise(),
+                subdirectory: if subdirectory == PathBuf::new() {
+                    None
+                } else {
+                    Some(subdirectory)
+                },
+                url,
+            });
+        }
+
         if editable {
             Ok(RequirementSource::Directory {
                 install_path,
@@ -665,6 +755,10 @@ fn path_source(
             })
         }
     } else {
+        // TODO(charlie): If a Git repo contains a source that points to a file, what should we do?
+        if git_member.is_some() {
+            return Err(LoweringError::GitFile(url.to_string()));
+        }
         if editable {
             return Err(LoweringError::EditableFile(url.to_string()));
         }
