@@ -143,6 +143,13 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
             return Ok(None);
         };
 
+        // Consider the dependencies to be "direct" if the requirement is a local source tree.
+        let direct = if let Dist::Source(source_dist) = &dist {
+            source_dist.as_path().is_some_and(std::path::Path::is_dir)
+        } else {
+            false
+        };
+
         // Fetch the metadata for the distribution.
         let metadata = {
             let id = dist.version_id();
@@ -167,16 +174,7 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
                     .database
                     .get_or_build_wheel_metadata(&dist, self.hasher.get(&dist))
                     .await
-                    .map_err(|err| match &dist {
-                        Dist::Built(built) => Error::Download(built.clone(), err),
-                        Dist::Source(source) => {
-                            if source.is_local() {
-                                Error::Build(source.clone(), err)
-                            } else {
-                                Error::DownloadAndBuild(source.clone(), err)
-                            }
-                        }
-                    })?;
+                    .map_err(|err| Error::from_dist(dist, err))?;
 
                 let metadata = archive.metadata.clone();
 
@@ -218,13 +216,6 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
             })
             .collect();
 
-        // Consider the dependencies to be "direct" if the requirement is a local source tree.
-        let direct = if let Dist::Source(source_dist) = &dist {
-            source_dist.as_path().is_some_and(std::path::Path::is_dir)
-        } else {
-            false
-        };
-
         // Return the requirements from the metadata.
         Ok(Some(RequestedRequirements::new(
             requirement.extras,
