@@ -43,34 +43,34 @@ pub(crate) fn marker_reachability<T>(
         fork_markers
             .iter()
             .fold(UniversalMarker::FALSE, |mut acc, marker| {
-                acc.or(marker.clone());
+                acc.or(*marker);
                 acc
             })
     };
     for root_index in &queue {
-        reachability.insert(*root_index, root_markers.clone());
+        reachability.insert(*root_index, root_markers);
     }
 
     // Propagate all markers through the graph, so that the eventual marker for each node is the
     // union of the markers of each path we can reach the node by.
     while let Some(parent_index) = queue.pop() {
-        let marker = reachability[&parent_index].clone();
+        let marker = reachability[&parent_index];
         for child_edge in graph.edges_directed(parent_index, Direction::Outgoing) {
             // The marker for all paths to the child through the parent.
-            let mut child_marker = child_edge.weight().clone();
-            child_marker.and(marker.clone());
+            let mut child_marker = *child_edge.weight();
+            child_marker.and(marker);
             match reachability.entry(child_edge.target()) {
                 Entry::Occupied(mut existing) => {
                     // If the marker is a subset of the existing marker (A ⊆ B exactly if
                     // A ∪ B = A), updating the child wouldn't change child's marker.
-                    child_marker.or(existing.get().clone());
+                    child_marker.or(*existing.get());
                     if &child_marker != existing.get() {
                         existing.insert(child_marker);
                         queue.push(child_edge.target());
                     }
                 }
                 Entry::Vacant(vacant) => {
-                    vacant.insert(child_marker.clone());
+                    vacant.insert(child_marker);
                     queue.push(child_edge.target());
                 }
             }
