@@ -3,7 +3,7 @@ use petgraph::Graph;
 use rustc_hash::{FxBuildHasher, FxHashMap, FxHashSet};
 use std::collections::hash_map::Entry;
 use std::collections::{BTreeMap, VecDeque};
-
+use std::slice;
 use uv_configuration::{BuildOptions, DevGroupsManifest, ExtrasSpecification, InstallOptions};
 use uv_distribution_types::{Edge, Node, Resolution, ResolvedDist};
 use uv_normalize::{ExtraName, GroupName, PackageName, DEV_DEPENDENCIES};
@@ -257,7 +257,7 @@ impl<'env> InstallTarget<'env> {
                     //
                     // FIXME: Make the above true. We aren't actually checking
                     // the conflict marker yet.
-                    Edge::Dev(group.clone(), dep.complexified_marker.pep508().clone()),
+                    Edge::Dev(group.clone(), dep.complexified_marker.pep508()),
                 );
 
                 // Push its dependencies on the queue.
@@ -329,11 +329,7 @@ impl<'env> InstallTarget<'env> {
             };
 
             // Add the edge.
-            petgraph.add_edge(
-                root,
-                index,
-                Edge::Dev(group.clone(), dependency.marker.clone()),
-            );
+            petgraph.add_edge(root, index, Edge::Dev(group.clone(), dependency.marker));
 
             // Push its dependencies on the queue.
             if seen.insert((&dist.id, None)) {
@@ -359,7 +355,10 @@ impl<'env> InstallTarget<'env> {
                 Either::Right(package.dependencies.iter())
             };
             for dep in deps {
-                if !dep.complexified_marker.evaluate(marker_env, &[]) {
+                if !dep
+                    .complexified_marker
+                    .evaluate(marker_env, extra.map(slice::from_ref).unwrap_or_default())
+                {
                     continue;
                 }
 
@@ -389,9 +388,9 @@ impl<'env> InstallTarget<'env> {
                     index,
                     dep_index,
                     if let Some(extra) = extra {
-                        Edge::Optional(extra.clone(), dep.complexified_marker.pep508().clone())
+                        Edge::Optional(extra.clone(), dep.complexified_marker.pep508())
                     } else {
-                        Edge::Prod(dep.complexified_marker.pep508().clone())
+                        Edge::Prod(dep.complexified_marker.pep508())
                     },
                 );
 
