@@ -21,7 +21,7 @@ pub(crate) struct RequirementsTxtDist<'dist> {
     pub(crate) dist: &'dist ResolvedDist,
     pub(crate) version: &'dist Version,
     pub(crate) hashes: &'dist [HashDigest],
-    pub(crate) markers: &'dist MarkerTree,
+    pub(crate) markers: MarkerTree,
     pub(crate) extras: Vec<ExtraName>,
 }
 
@@ -45,7 +45,7 @@ impl<'dist> RequirementsTxtDist<'dist> {
             }
         }
 
-        // If the URL is not _definitively_ an absolute `file://` URL, write it as a relative path.
+        // If the URL is not _definitively_ a `file://` URL, write it as a relative path.
         if self.dist.is_local() {
             if let VersionOrUrlRef::Url(url) = self.dist.version_or_url() {
                 let given = url.verbatim();
@@ -72,11 +72,12 @@ impl<'dist> RequirementsTxtDist<'dist> {
                                     {
                                         Some(Cow::Owned(path.to_string()))
                                     } else {
+                                        // Ex) `file:///flask-3.0.3-py3-none-any.whl`
                                         None
                                     }
                                 } else {
                                     // Ex) `file:./flask-3.0.3-py3-none-any.whl`
-                                    Some(given)
+                                    None
                                 }
                             }
                             Some(_) => None,
@@ -93,7 +94,7 @@ impl<'dist> RequirementsTxtDist<'dist> {
                 };
                 if let Some(given) = given {
                     return if let Some(markers) =
-                        SimplifiedMarkerTree::new(requires_python, self.markers.clone())
+                        SimplifiedMarkerTree::new(requires_python, self.markers)
                             .try_to_string()
                             .filter(|_| include_markers)
                     {
@@ -106,7 +107,7 @@ impl<'dist> RequirementsTxtDist<'dist> {
         }
 
         if self.extras.is_empty() {
-            if let Some(markers) = SimplifiedMarkerTree::new(requires_python, self.markers.clone())
+            if let Some(markers) = SimplifiedMarkerTree::new(requires_python, self.markers)
                 .try_to_string()
                 .filter(|_| include_markers)
             {
@@ -118,7 +119,7 @@ impl<'dist> RequirementsTxtDist<'dist> {
             let mut extras = self.extras.clone();
             extras.sort_unstable();
             extras.dedup();
-            if let Some(markers) = SimplifiedMarkerTree::new(requires_python, self.markers.clone())
+            if let Some(markers) = SimplifiedMarkerTree::new(requires_python, self.markers)
                 .try_to_string()
                 .filter(|_| include_markers)
             {
