@@ -47,14 +47,11 @@ pub(crate) use tool::uninstall::uninstall as tool_uninstall;
 pub(crate) use tool::update_shell::update_shell as tool_update_shell;
 pub(crate) use tool::upgrade::upgrade as tool_upgrade;
 use uv_cache::Cache;
-use uv_distribution_types::{IndexCapabilities, InstalledMetadata};
+use uv_distribution_types::InstalledMetadata;
 use uv_fs::Simplified;
-use uv_git::GitResolver;
 use uv_installer::compile_tree;
 use uv_normalize::PackageName;
 use uv_python::PythonEnvironment;
-use uv_resolver::InMemoryIndex;
-use uv_types::InFlight;
 pub(crate) use venv::venv;
 pub(crate) use version::version;
 
@@ -194,19 +191,6 @@ pub(super) fn human_readable_bytes(bytes: u64) -> (f32, &'static str) {
     (bytes / 1024_f32.powi(i as i32), UNITS[i])
 }
 
-/// Shared state used during resolution and installation.
-#[derive(Default)]
-pub(crate) struct SharedState {
-    /// The resolved Git references.
-    pub(crate) git: GitResolver,
-    /// The fetched package versions and metadata.
-    pub(crate) index: InMemoryIndex,
-    /// The downloaded distributions.
-    pub(crate) in_flight: InFlight,
-    /// The discovered capabilities for each registry index.
-    pub(crate) capabilities: IndexCapabilities,
-}
-
 /// A multicasting writer that writes to both the standard output and an output file, if present.
 #[allow(clippy::disallowed_types)]
 struct OutputWriter<'a> {
