@@ -423,8 +423,8 @@ async fn init_project(
                         &client_builder,
                         cache,
                         Some(&reporter),
-                        install_mirrors.python_install_mirror,
-                        install_mirrors.pypy_install_mirror,
+                        install_mirrors.python_install_mirror.as_deref(),
+                        install_mirrors.pypy_install_mirror.as_deref(),
                     )
                     .await?
                     .into_interpreter();
@@ -447,8 +447,8 @@ async fn init_project(
                     &client_builder,
                     cache,
                     Some(&reporter),
-                    install_mirrors.python_install_mirror,
-                    install_mirrors.pypy_install_mirror,
+                    install_mirrors.python_install_mirror.as_deref(),
+                    install_mirrors.pypy_install_mirror.as_deref(),
                 )
                 .await?
                 .into_interpreter();
@@ -509,8 +509,8 @@ async fn init_project(
                 &client_builder,
                 cache,
                 Some(&reporter),
-                install_mirrors.python_install_mirror,
-                install_mirrors.pypy_install_mirror,
+                install_mirrors.python_install_mirror.as_deref(),
+                install_mirrors.pypy_install_mirror.as_deref(),
             )
             .await?
             .into_interpreter();
@@ -533,8 +533,8 @@ async fn init_project(
             &client_builder,
             cache,
             Some(&reporter),
-            install_mirrors.python_install_mirror,
-            install_mirrors.pypy_install_mirror,
+            install_mirrors.python_install_mirror.as_deref(),
+            install_mirrors.pypy_install_mirror.as_deref(),
         )
         .await?
         .into_interpreter();
