@@ -14,7 +14,7 @@ use uv_configuration::{
     Concurrency, Constraints, ExtrasSpecification, LowerBound, Reinstall, SourceStrategy,
     TrustedHost, Upgrade,
 };
-use uv_dispatch::BuildDispatch;
+use uv_dispatch::{BuildDispatch, SharedState};
 use uv_distribution::DistributionDatabase;
 use uv_distribution_types::{
     DependencyMetadata, Index, IndexLocations, NameRequirementSpecification,
@@ -39,9 +39,7 @@ use uv_warnings::{warn_user, warn_user_once};
 use uv_workspace::{DiscoveryOptions, Workspace};
 
 use crate::commands::pip::loggers::{DefaultResolveLogger, ResolveLogger, SummaryResolveLogger};
-use crate::commands::project::{
-    find_requires_python, ProjectError, ProjectInterpreter, SharedState,
-};
+use crate::commands::project::{find_requires_python, ProjectError, ProjectInterpreter};
 use crate::commands::reporters::ResolverReporter;
 use crate::commands::{diagnostics, pip, ExitStatus};
 use crate::printer::Printer;
@@ -361,9 +359,9 @@ async fn do_lock(
                 .iter()
                 .zip(environments.as_markers().iter().skip(1))
             {
-                if !lhs.is_disjoint(rhs) {
+                if !lhs.is_disjoint(*rhs) {
                     let mut hint = lhs.negate();
-                    hint.and(rhs.clone());
+                    hint.and(*rhs);
 
                     let lhs = lhs
                         .contents()
@@ -413,6 +411,7 @@ async fn do_lock(
         .map(SupportedEnvironments::as_markers)
         .into_iter()
         .flatten()
+        .copied()
     {
         if requires_python.to_marker_tree().is_disjoint(environment) {
             return if let Some(contents) = environment.contents() {
@@ -493,10 +492,7 @@ async fn do_lock(
         index_locations,
         &flat_index,
         dependency_metadata,
-        &state.index,
-        &state.git,
-        &state.capabilities,
-        &state.in_flight,
+        state.clone(),
         index_strategy,
         config_setting,
         build_isolation,
@@ -528,7 +524,7 @@ async fn do_lock(
             upgrade,
             &options,
             &hasher,
-            &state.index,
+            state.index(),
             &database,
             printer,
         )
@@ -578,7 +574,7 @@ async fn do_lock(
             // Populate the Git resolver.
             for ResolvedRepositoryReference { reference, sha } in git {
                 debug!("Inserting Git reference into resolver: `{reference:?}` at `{sha}`");
-                state.git.insert(reference, sha);
+                state.git().insert(reference, sha);
             }
 
             // Determine whether we can reuse the existing package forks.
@@ -604,8 +600,8 @@ async fn do_lock(
                         // `ResolverEnvironment`.
                         lock.fork_markers()
                             .iter()
+                            .copied()
                             .map(UniversalMarker::pep508)
-                            .cloned()
                             .collect()
                     })
                     .unwrap_or_else(|| {
@@ -618,7 +614,7 @@ async fn do_lock(
 
             // Resolve the requirements.
             let resolution = pip::operations::resolve(
-                ExtrasResolver::new(&hasher, &state.index, database)
+                ExtrasResolver::new(&hasher, state.index(), database)
                     .with_reporter(ResolverReporter::from(printer))
                     .resolve(workspace.members_requirements())
                     .await
@@ -654,7 +650,7 @@ async fn do_lock(
                 workspace.conflicts(),
                 &client,
                 &flat_index,
-                &state.index,
+                state.index(),
                 &build_dispatch,
                 concurrency,
                 options,
@@ -814,7 +810,7 @@ impl ValidatedLock {
             .map(SupportedEnvironments::as_markers)
             .unwrap_or_default()
             .iter()
-            .cloned()
+            .copied()
             .map(|marker| lock.simplify_environment(marker))
             .collect::<Vec<_>>();
         if expected != actual {
