@@ -219,7 +219,8 @@ impl TestContext {
     pub fn with_filtered_python_keys(mut self) -> Self {
         // Filter platform keys
         self.filters.push((
-            r"((?:cpython|pypy)-\d+\.\d+(?:\.(?:\[X\]|\d+))?[a-z]?(?:\+[a-z]+)?)-.*".to_string(),
+            r"((?:cpython|pypy)-\d+\.\d+(?:\.(?:\[X\]|\d+))?[a-z]?(?:\+[a-z]+)?)-[a-z0-9]+-[a-z0-9_]+-[a-z]+"
+                .to_string(),
             "$1-[PLATFORM]".to_string(),
         ));
         self
@@ -315,7 +316,7 @@ impl TestContext {
         // Exclude `link-mode` on Windows since we set it in the remote test suite
         if cfg!(windows) {
             filters.push(("--link-mode <LINK_MODE> ".to_string(), String::new()));
-            filters.push(((r#"link-mode = "copy"\n"#).to_string(), String::new()));
+            filters.push((r#"link-mode = "copy"\n"#.to_string(), String::new()));
         }
 
         filters.extend(
