@@ -516,6 +516,20 @@ fn help_subsubcommand() {
               
               Implies `--reinstall`.
 
+          --default
+              Use as the default Python version.
+              
+              By default, only a `python{major}.{minor}` executable is installed, e.g., `python3.10`.
+              When the `--default` flag is used, `python{major}`, e.g., `python3`, and `python`
+              executables are also installed.
+              
+              Alternative Python variants will still include their tag. For example, installing
+              3.13+freethreaded with `--default` will include in `python3t` and `pythont`, not `python3`
+              and `python`.
+              
+              If multiple Python versions are requested during the installation, the first request will
+              be the default.
+
     Cache options:
       -n, --no-cache
               Avoid reading from or writing to the cache, instead using a temporary directory for the
@@ -751,6 +765,7 @@ fn help_flag_subsubcommand() {
                                        installations [env: UV_PYPY_INSTALL_MIRROR=]
       -r, --reinstall                  Reinstall the requested Python version, if it's already installed
       -f, --force                      Replace existing Python executables during installation
+          --default                    Use as the default Python version
 
     Cache options:
       -n, --no-cache               Avoid reading from or writing to the cache, instead using a temporary
