@@ -2610,7 +2610,7 @@ fn run_isolated_incompatible_python() -> Result<()> {
 
     ----- stderr -----
     Using CPython 3.8.[X] interpreter at: [PYTHON-3.8]
-    error: The Python request from `.python-version` resolved to Python 3.8.[X], which is incompatible with the project's Python requirement: `>=3.12`
+    error: The Python request from `.python-version` resolved to Python 3.8.[X], which is incompatible with the project's Python requirement: `>=3.12`. Use `uv python pin` to update the `.python-version` file to a compatible version.
     "###);
 
     // ...even if `--isolated` is provided.
@@ -2620,7 +2620,7 @@ fn run_isolated_incompatible_python() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    error: The Python request from `.python-version` resolved to Python 3.8.[X], which is incompatible with the project's Python requirement: `>=3.12`
+    error: The Python request from `.python-version` resolved to Python 3.8.[X], which is incompatible with the project's Python requirement: `>=3.12`. Use `uv python pin` to update the `.python-version` file to a compatible version.
     "###);
 
     Ok(())
@@ -3201,3 +3201,95 @@ fn run_with_not_existing_env_file() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn run_with_extra_conflict() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! { r#"
+        [project]
+        name = "project"
+        version = "0.1.0"
+        requires-python = ">=3.12.0"
+        dependencies = []
+
+        [project.optional-dependencies]
+        foo = ["iniconfig==2.0.0"]
+        bar = ["iniconfig==1.1.1"]
+
+        [tool.uv]
+        conflicts = [
+          [
+            { extra = "foo" },
+            { extra = "bar" },
+          ],
+        ]
+        "#
+    })?;
+
+    uv_snapshot!(context.filters(), context.run()
+        .arg("--extra")
+        .arg("foo")
+        .arg("python")
+        .arg("-c")
+        .arg("import iniconfig"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 3 packages in [TIME]
+    Prepared 1 package in [TIME]
+    Installed 1 package in [TIME]
+     + iniconfig==2.0.0
+    "###);
+
+    Ok(())
+}
+
+#[test]
+fn run_with_group_conflict() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! { r#"
+        [project]
+        name = "project"
+        version = "0.1.0"
+        requires-python = ">=3.12.0"
+        dependencies = []
+
+        [dependency-groups]
+        foo = ["iniconfig==2.0.0"]
+        bar = ["iniconfig==1.1.1"]
+
+        [tool.uv]
+        conflicts = [
+          [
+            { group = "foo" },
+            { group = "bar" },
+          ],
+        ]
+        "#
+    })?;
+
+    uv_snapshot!(context.filters(), context.run()
+        .arg("--group")
+        .arg("foo")
+        .arg("python")
+        .arg("-c")
+        .arg("import iniconfig"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 3 packages in [TIME]
+    Prepared 1 package in [TIME]
+    Installed 1 package in [TIME]
+     + iniconfig==2.0.0
+    "###);
+
+    Ok(())
+}
